angular.module('starter.services', ['ionic'])
    .factory('TokenInterceptor', function ($q, $window, AuthenticationService, $location) {
        return {
            request: function (config) {
                config.headers = config.headers || {};
                if ($window.localStorage.token) {
                    config.headers.Authorization = 'Bearer ' + $window.localStorage.token;
                    if (config.url.indexOf('.json') != -1) {
                        config.url += (config.url.indexOf('?') == -1 ? '?' : '&') + 'sid_=' + $window.localStorage.token;
                    }
                }
                return config;
            },

            requestError: function (rejection) {
                return $q.reject(rejection);
            },

            /* Set Authentication.isAuthenticated to true if 200 received */
            response: function (response) {
                if (response != null && response.status == 200 && $window.localStorage.token && !AuthenticationService.isAuthenticated) {
                    AuthenticationService.isAuthenticated = true;
                }
                return response || $q.when(response);
            },

            /* Revoke client authentication if 401 is received */
            responseError: function (rejection) {
                if (rejection != null && rejection.status === 401 && ($window.localStorage.token || !AuthenticationService.isAuthenticated)) {
                    delete $window.localStorage.token;
                    //AuthenticationService.isAuthenticated = false;
                    $location.path("/login");
                }

                return $q.reject(rejection);
            }
        };
    })

    .factory('AuthenticationService', function () {
        var auth = {
            isAuthenticated: false
        }
        return auth;
    })


// /**
//  * 拍照功能
//  */
//     .factory('Camera', function ($q) {
//         return {
//             getPicture: function (options) {
//                 var q = $q.defer();
//                 navigator.camera.getPicture(function (result) {
//                     // Do any magic you need
//                     q.resolve(result);
//                 }, function (err) {
//                     q.reject(err);
//                 }, options);
//
//                 return q.promise;
//             }
//         }
//     })

       /**
 * Upyun认证数据
 */
    .factory('Upyun', function ($http) {
        return {
            token: function (name, size) {
                return $http.jsonp("http://transfer.impress.pw/upyun?callback=JSON_CALLBACK", {
                    cache: false
                });
            }
        }
    })

    .factory('Message', function ($http, apiUrl, $XMPopup) {
        return {
            remove: function (sysNotifyRecordId, index, datas) {
                $http.get(apiUrl + 'user/deleteSysNotifyRecord.json?id=' + sysNotifyRecordId)
                    .success(function (data, status, headers, config) {
                        if (data.status == 'SUCCESS') {
                            datas.splice(index, 1);
                        } else {
                            $XMPopup.alert(data.message);
                        }
                    })
            },
            linkPrompt:function(){
                $XMPopup.alert("请到pc端操作!");
            }
        }
    })

    /**
     * 我收藏的/关注的
     */
    .factory('UserFav', function ($http, apiUrl, $XMPopup, $location) {
        return {
            fav: function (id, isFav,referType) {//（取消）关注 or （取消）收藏（课程、机构、讲师）
                $http.get(apiUrl + 'user/doFav.json?id=' + id + '&type='+referType+'&fav=' + isFav)
                    .success(function (data, status, headers, config) {
                        if (data.status == 'SUCCESS') {
                            //
                        } else if (data.status == 'WARNING') {
                            $location.path('/login');
                        } else {
                            $XMPopup.alert(data.message);
                        }
                    });
            }
        }
    })

    .factory('UserOrder', function ($http, apiUrl, $ionicPopup, $location,$XMPopup, AlipayService) {
        return {
            showCancelConfirm: function (orderPayInfoId, index, payStatus, datas) {
                var confirmPopup = $ionicPopup.confirm({
                    title: '取消订单',
                    template: '您确定要取消订单吗？',//Are you sure you want to cancel this order?
                    okText: '确定', // String (默认: 'OK')。OK按钮的文字。
                    cancelText: '再看看' // String (默认: 'Cancel')。一个取消按钮的文字。
                });

                confirmPopup.then(function (res) {
                    if (res) {
                        $http.get(apiUrl + 'user/cancelOrder.json?orderPayInfoId=' + orderPayInfoId).
                            success(function (data, status, headers, config) {
                                if (payStatus == '' || payStatus == undefined) {//全部
                                    datas[index].payStatus = 'CANCELED';
                                    angular.forEach(datas[index].orderFormList, function (v, k) {
                                        v.status = 'CANCELED';
                                    })
                                } else if (payStatus == 'WAITING_PAY') {//待付款
                                    datas.splice(index, 1);
                                }
                            })
                            .error(function (data, status, headers, config) {

                            })
                    }
                });
            },
            pay: function (orderPayInfoId) {
                var prefix = 'account';
                console.log($location.path());
                if ($location.path().indexOf('dash') > 0) {
                    prefix = 'dash';
                } else if ($location.path().indexOf('course') > 0) {
                    prefix = 'course';
                } else if ($location.path().indexOf('free') > 0) {
                    prefix = 'free';
                }
                $location.path('/tab/' + prefix + 'Payment/USER_ORDER/' + orderPayInfoId);
            },
            confirmDeliver: function(orderFormId){
                var confirmPopup = $ionicPopup.confirm({
                    title: '确认收货',
                    template: '您确认已经收到货物了吗？',
                    okText: '确定', // String (默认: 'OK')。OK按钮的文字。
                    cancelText: '再看看' // String (默认: 'Cancel')。一个取消按钮的文字。
                });

                confirmPopup.then(function (res) {
                    if (res) {
                        $http.post(apiUrl + 'user/order/confirmDeliver.json?orderFormId=' + orderFormId)
                            .success(function (data) {
                                if (data.status == "SUCCESS") {
                                    $location.path('/tab/dashOrder/WAITING_PAY' );
                                } else {
                                    $XMPopup.alert("抱歉！确认失败！");
                                }

                            });
                    }
                });
            }
        }
    })

    /**
 * 立即购买
 */
    .factory('BuyCourse', function ($http, apiUrl, $XMPopup, $location, $window) {
        return {
            buyOnlineCourse: function (course) {//TODO 暂时未用
                if (!$window.localStorage.token) {
                    $location.path('/login');
                }
                //只能购买在线课
                //if ("ONLINE_COURSE" != course.type) {
                //    $XMPopup.alert("手机端暂不支持该类型课程的购买，购买请到PC端");
                //    return;
                //}

                var prefix = 'dash';
                if ($location.path().indexOf('userCourseDetail') > 0) {
                    prefix = 'account';
                } else if ($location.path().indexOf('courseDetail') > 0) {
                    prefix = 'course';
                }

                $http.post(apiUrl + 'user/order/submitOrder.json?goodsItemId=' + course.goods.goodsItem.goodsItemId)
                    .success(function (data, status, headers, config) {
                        if (data.status == "SUCCESS") {
                            $location.path('/tab/' + prefix + 'Payment/' + data.data);
                        } else {
                            $XMPopup.alert("抱歉！购买错误，请试试其他课程！");
                        }

                    });
            }


        }
    })

    .factory('AlipayService',function($http,$timeout,apiUrl,$XMPopup,$location){

         //支付确定弹窗
        var showConfirm = function () {
            var rootNamePrefix = 'account';
            if ($location.path().indexOf('dash') > 0) {
                rootNamePrefix = 'dash';
            } else if ($location.path().indexOf('course') > 0) {
                rootNamePrefix = 'course';
            } else if ($location.path().indexOf('free') > 0) {
                rootNamePrefix = 'free';
            }

            var confirmPopup = $XMPopup.confirm({
                title: '支付提示',
                template: '支付是否成功？',
                buttons: [
                    { //Array[Object] (可选)。放在弹窗footer内的按钮。
                        text: '不成功',
                        onTap: function (e) {
                            // 当点击时，e.preventDefault() 会阻止弹窗关闭。
                            //e.preventDefault();
                            //跳转到我的订单页面
                            $location.path("/tab/" + rootNamePrefix + "Order/PAY_FAILED");
                        }
                    },
                    {
                        text: '成功',
                        onTap: function (e) {
                            // 返回的值会导致处理给定的值。
                            //return $scope.data.response;
                            //跳转到我的课程页面
                            $location.path("/tab/" + rootNamePrefix + "UCourse");
                        }
                    }
                ]
            });
            confirmPopup.then(function (res) {
                /*if(res) {
                 console.log('You are sure');
                 } else {
                 console.log('You are not sure');
                 }*/
            });
        };

        return {
            pay: function (orderPayInfoId, payBtnDisabled) {
                $http.get(apiUrl + 'user/order/pay.json?payType=ALIPAY&orderPayInfoId=' + orderPayInfoId)
                    .success(function (data, status, headers, config) {
                        if (data.status == "SUCCESS") {
                            //禁用去付款按钮
                            payBtnDisabled = true;
                            //弹出支付成功与否的提示框
                            $timeout(function () {
                                showConfirm();
                            }, 3000);
                            var payInfo = data.data;
                            //调用支付宝
                            window.alipay.pay({
                                tradeNo: payInfo.payNumber,
                                subject: payInfo.paySubject,
                                body: payInfo.payContext,
                                price: payInfo.payAmount,
                                notifyUrl: payInfo.notifyUrl
                            }, function(successResults){
                            }, function(errorResults){
                            });
                        } else {
                            $XMPopup.alert(data.message);
                        }
                    });
            }


        }
    })

    /**
     * 评论相关
     */
    .factory('CommentStart', function () {
        return{
            getAvyStyle: function (num) {
                if (typeof num == 'number') {
                    return "width:" + num * 20 + '%';
                }
                return "width:0%";
            }
        }
    })

    .factory('$XMPopup', function ($ionicPopup){
        return {
            alert : function(message,title){
                if (!title) {
                    title = '提示';
                }

                return $ionicPopup.alert({
                    title: title,
                    template: message,
                    okText: '确定'
                });
            },

            confirm : function(obj){
                return $ionicPopup.confirm(obj);
            }
        }
    })
    .factory('City',function($window,$rootScope){
        var historyList = [];
        var historyArr = $window.localStorage.cityHistories;
        if ($window.localStorage.cityHistories != undefined) {
            historyList = historyArr.split(',').reverse();
        }

        var cityHistories = [];
        if (historyList.length > 0) {
            var i = 0;
            for (i in historyList) {
                cityHistories.push({
                    "name": historyList[i],
                    "key": "最近访问城市"
                });
            }
        }

        var city= [
            {
                "定位":[
                    {
                        "name": $rootScope.curCityName,
                        "key":"定位"
                    }
                ],
                "最近访问城市":cityHistories,
                "热门":[

                    {
                        "name": "北京",
                        "key":"热门"
                    },
                    {
                        "name": "上海",
                        "key":"热门"
                    },
                    {
                        "name": "广州",
                        "key":"热门"
                    },
                    {
                        "name": "深圳",
                        "key":"热门"
                    },
                    {
                        "name": "成都",
                        "key":"热门"
                    },

                    {
                        "name": "重庆",
                        "key":"热门"
                    },
                    {
                        "name": "天津",
                        "key":"热门"
                    },
                    {
                        "name": "杭州",
                        "key":"热门"
                    },
                    {
                        "name": "南京",
                        "key":"热门"
                    },
                    {
                        "name": "苏州",
                        "key":"热门"
                    },
                    {
                        "name": "武汉",
                        "key":"热门"
                    },

                    {
                        "name": "西安",
                        "key":"热门"
                    }

                ],
                "A": [
                    {
                        "name": "阿坝",
                        "key":"A"
                    },
                    {
                        "name": "阿拉善",
                        "key":"A"
                    },
                    {
                        "name": "阿里",
                        "key":"A"
                    },
                    {
                        "name": "安康",
                        "key":"A"
                    },
                    {
                        "name": "安庆",
                        "key":"A"
                    },

                    {
                        "name": "鞍山",
                        "key":"A"
                    }
                    ,
                    {
                        "name": "安顺",
                        "key":"A"
                    }
                    ,
                    {
                        "name": "安阳",
                        "key":"A"
                    }
                    ,
                    {
                        "name": "澳门",
                        "key":"A"
                    }
                ],
                "B": [
                    {
                        "name": "北京",
                        "key":"B"
                    },
                    {
                        "name": "白银",
                        "key":"B"
                    },
                    {
                        "name": "保定",
                        "key":"B"
                    },
                    {
                        "name": "宝鸡",
                        "key":"B"
                    },
                    {
                        "name": "保山",
                        "key":"B"
                    },
                    {
                        "name": "包头",
                        "key":"B"
                    },
                    {
                        "name": "巴中",
                        "key":"B"
                    }
                    ,
                    {
                        "name": "北海",
                        "key":"B"
                    }
                    ,
                    {
                        "name": "蚌埠",
                        "key":"B"
                    }
                    ,
                    {
                        "name": "本溪",
                        "key":"B"
                    }
                    ,
                    {
                        "name": "毕节",
                        "key":"B"
                    }
                    ,
                    {
                        "name": "滨州",
                        "key":"B"
                    }
                    ,
                    {
                        "name": "百色",
                        "key":"B"
                    }
                    ,
                    {
                        "name": "亳州",
                        "key":"B"
                    }
                ],
                "C": [
                    {
                        "name": "重庆",
                        "key":"C"
                    },
                    {
                        "name": "成都",
                        "key":"C"
                    },
                    {
                        "name": "长沙",
                        "key":"C"
                    },
                    {
                        "name": "长春",
                        "key":"C"
                    },
                    {
                        "name": "沧州",
                        "key":"C"
                    },
                    {
                        "name": "常德",
                        "key":"C"
                    },
                    {
                        "name": "昌都",
                        "key":"C"
                    }
                    ,
                    {
                        "name": "长治",
                        "key":"C"
                    }
                    ,
                    {
                        "name": "常州",
                        "key":"C"
                    }
                    ,
                    {
                        "name": "巢湖",
                        "key":"C"
                    }
                    ,
                    {
                        "name": "潮州",
                        "key":"C"
                    }
                    ,
                    {
                        "name": "承德",
                        "key":"C"
                    }
                    ,
                    {
                        "name": "郴州",
                        "key":"C"
                    }
                    ,
                    {
                        "name": "赤峰",
                        "key":"C"
                    }
                    ,
                    {
                        "name": "池州",
                        "key":"C"
                    }
                    ,
                    {
                        "name": "崇左",
                        "key":"C"
                    }
                    ,
                    {
                        "name": "楚雄",
                        "key":"C"
                    }
                    ,
                    {
                        "name": "滁州",
                        "key":"C"
                    }
                    ,
                    {
                        "name": "朝阳",
                        "key":"C"
                    }
                ],
                "D": [
                    {
                        "name": "大连",
                        "key":"D"
                    },
                    {
                        "name": "东莞",
                        "key":"D"
                    },
                    {
                        "name": "大理",
                        "key":"D"
                    },
                    {
                        "name": "丹东",
                        "key":"D"
                    },
                    {
                        "name": "大庆",
                        "key":"D"
                    },
                    {
                        "name": "大同",
                        "key":"D"
                    },
                    {
                        "name": "大兴安岭",
                        "key":"D"
                    }
                    ,
                    {
                        "name": "德宏",
                        "key":"D"
                    }
                    ,
                    {
                        "name": "德阳",
                        "key":"D"
                    }
                    ,
                    {
                        "name": "德州",
                        "key":"D"
                    }
                    ,
                    {
                        "name": "定西",
                        "key":"D"
                    }
                    ,
                    {
                        "name": "迪庆",
                        "key":"D"
                    }
                    ,
                    {
                        "name": "东营",
                        "key":"D"
                    }

                ],
                "E": [
                    {
                        "name": "鄂尔多斯",
                        "key":"E"
                    }
                    ,
                    {
                        "name": "恩施",
                        "key":"E"
                    }
                    ,
                    {
                        "name": "鄂州",
                        "key":"E"
                    }
                ],
                "F": [
                    {
                        "name": "福州",
                        "key":"F"
                    }
                    ,
                    {
                        "name": "防城港",
                        "key":"F"
                    }
                    ,
                    {
                        "name": "佛山",
                        "key":"F"
                    }
                    ,
                    {
                        "name": "抚顺",
                        "key":"F"
                    }
                    ,
                    {
                        "name": "抚州",
                        "key":"F"
                    }
                    ,
                    {
                        "name": "阜新",
                        "key":"F"
                    }
                    ,
                    {
                        "name": "阜阳",
                        "key":"F"
                    }
                ]
                ,
                "G":[
                    {
                        "name": "广州",
                        "key":"G"
                    },
                    {
                        "name": "赣州",
                        "key":"G"
                    },
                    {
                        "name": "桂林",
                        "key":"G"
                    },
                    {
                        "name": "贵阳",
                        "key":"G"
                    },
                    {
                        "name": "甘南",
                        "key":"G"
                    },

                    {
                        "name": "甘孜",
                        "key":"G"
                    },
                    {
                        "name": "广安",
                        "key":"G"
                    }
                    ,
                    {
                        "name": "广元",
                        "key":"G"
                    }
                    ,
                    {
                        "name": "果洛",
                        "key":"G"
                    }
                    ,
                    {
                        "name": "贵港",
                        "key":"G"
                    }

                ],

                "H":[
                    {
                        "name": "杭州",
                        "key":"H"
                    },
                    {
                        "name": "哈尔滨",
                        "key":"H"
                    },
                    {
                        "name": "合肥",
                        "key":"H"
                    },
                    {
                        "name": "海口",
                        "key":"H"
                    },
                    {
                        "name": "海东",
                        "key":"H"
                    },
                    {
                        "name": "海北",
                        "key":"H"
                    },
                    {
                        "name": "海南",
                        "key":"H"
                    }
                    ,
                    {
                        "name": "海西",
                        "key":"H"
                    }
                    ,
                    {
                        "name": "邯郸",
                        "key":"H"
                    }

                    ,
                    {
                        "name": "汉中",
                        "key":"H"
                    }
                    ,
                    {
                        "name": "鹤壁",
                        "key":"H"
                    }
                    ,
                    {
                        "name": "河池",
                        "key":"H"
                    }
                    ,
                    {
                        "name": "鹤岗",
                        "key":"H"
                    }
                    ,
                    {
                        "name": "黑河",
                        "key":"H"
                    }
                    ,
                    {
                        "name": "衡水",
                        "key":"H"
                    }
                    ,
                    {
                        "name": "衡阳",
                        "key":"H"
                    }

                    ,
                    {
                        "name": "河源",
                        "key":"H"
                    }
                    ,
                    {
                        "name": "贺州",
                        "key":"H"
                    }
                    ,
                    {
                        "name": "红河",
                        "key":"H"
                    }
                    ,
                    {
                        "name": "淮安",
                        "key":"H"
                    }
                    ,
                    {
                        "name": "淮北",
                        "key":"H"
                    }
                    ,
                    {
                        "name": "怀化",
                        "key":"H"
                    }
                    ,
                    {
                        "name": "淮南",
                        "key":"H"
                    }
                    ,

                    {
                        "name": "黄冈",
                        "key":"H"
                    }
                    ,
                    {
                        "name": "黄南",
                        "key":"H"
                    }
                    ,
                    {
                        "name": "黄山",
                        "key":"H"
                    },
                    {
                        "name": "黄石",
                        "key":"H"
                    },
                    {
                        "name": "惠州",
                        "key":"H"
                    },
                    {
                        "name": "葫芦岛",
                        "key":"H"
                    },
                    {
                        "name": "呼伦贝尔",
                        "key":"H"
                    },
                    {
                        "name": "湖州",
                        "key":"H"
                    }
                    ,
                    {
                        "name": "菏泽",
                        "key":"H"
                    }

                ],
                "J":[

                    {
                        "name": "济南",
                        "key":"J"
                    },
                    {
                        "name": "佳木斯",
                        "key":"J"
                    },
                    {
                        "name": "吉安",
                        "key":"J"
                    },
                    {
                        "name": "江门",
                        "key":"J"
                    },
                    {
                        "name": "焦作",
                        "key":"J"
                    },
                    {
                        "name": "嘉兴",
                        "key":"J"
                    },
                    {
                        "name": "嘉峪关",
                        "key":"J"
                    }
                    ,
                    {
                        "name": "揭阳",
                        "key":"J"
                    }
                    ,

                    {
                        "name": "吉林",
                        "key":"J"
                    }
                    ,
                    {
                        "name": "金昌",
                        "key":"J"
                    }
                    ,
                    {
                        "name": "晋城",
                        "key":"J"
                    }
                    ,
                    {
                        "name": "景德镇",
                        "key":"J"
                    }
                    ,
                    {
                        "name": "荆门",
                        "key":"J"
                    }
                    ,
                    {
                        "name": "荆州",
                        "key":"J"
                    }
                    ,
                    {
                        "name": "金华",
                        "key":"J"
                    }

                    ,
                    {
                        "name": "济宁",
                        "key":"J"
                    }
                    ,
                    {
                        "name": "晋中",
                        "key":"J"
                    }
                    ,
                    {
                        "name": "锦州",
                        "key":"J"
                    }
                    ,
                    {
                        "name": "九江",
                        "key":"J"
                    }
                    ,
                    {
                        "name": "酒泉",
                        "key":"J"
                    }
                ]
                ,
                "K":[
                    {
                        "name": "昆明",
                        "key":"K"

                    }
                    ,
                    {

                        "name": "开封",
                        "key":"K"
                    }
                ]
                ,

                "L":[
                    {
                        "name": "兰州",
                        "key":"L"
                    },
                    {
                        "name": "拉萨",
                        "key":"L"
                    },
                    {
                        "name": "来宾",
                        "key":"L"
                    },
                    {
                        "name": "莱芜",
                        "key":"L"
                    },
                    {
                        "name": "廊坊",
                        "key":"L"
                    },
                    {
                        "name": "乐山",
                        "key":"L"
                    },
                    {
                        "name": "凉山",
                        "key":"L"
                    }
                    ,
                    {
                        "name": "连云港",
                        "key":"L"
                    }

                    ,
                    {
                        "name": "聊城",
                        "key":"L"
                    }

                    ,
                    {
                        "name": "辽阳",
                        "key":"L"
                    }
                    ,
                    {
                        "name": "辽源",
                        "key":"L"
                    }
                    ,
                    {
                        "name": "丽江",
                        "key":"L"
                    }
                    ,
                    {
                        "name": "临沧",
                        "key":"L"
                    }
                    ,
                    {
                        "name": "临汾",
                        "key":"L"
                    }
                    ,
                    {
                        "name": "临夏",
                        "key":"L"
                    }
                    ,

                    {
                        "name": "临沂",
                        "key":"L"
                    }

                    ,
                    {
                        "name": "林芝",
                        "key":"L"
                    }
                    ,
                    {
                        "name": "丽水",
                        "key":"L"
                    }
                    ,
                    {
                        "name": "六安",
                        "key":"L"
                    }
                    ,
                    {
                        "name": "六盘水",
                        "key":"L"
                    }
                    ,
                    {
                        "name": "柳州",
                        "key":"L"
                    }
                    ,
                    {
                        "name": "陇南",
                        "key":"L"
                    }
                    ,

                    {
                        "name": "龙岩",
                        "key":"L"
                    }
                    ,

                    {
                        "name": "娄底",
                        "key":"L"
                    }
                    ,
                    {
                        "name": "漯河",
                        "key":"L"
                    }
                    ,
                    {
                        "name": "洛阳",
                        "key":"L"
                    },
                    {
                        "name": "泸州",
                        "key":"L"
                    },
                    {
                        "name": "吕梁",
                        "key":"L"
                    }

                ],

                "M": [
                    {
                        "name": "马鞍山",
                        "key":"M"
                    }
                    ,
                    {
                        "name": "茂名",
                        "key":"M"
                    }
                    ,
                    {
                        "name": "眉山",
                        "key":"M"
                    }
                    ,
                    {
                        "name": "梅州",
                        "key":"M"
                    }
                    ,
                    {
                        "name": "绵阳",
                        "key":"M"
                    }
                    ,
                    {
                        "name": "牡丹江",
                        "key":"M"
                    }

                ],
                "N":[

                    {
                        "name": "南京",
                        "key":"N"
                    },
                    {
                        "name": "南昌",
                        "key":"N"
                    },
                    {
                        "name": "南宁",
                        "key":"N"
                    },
                    {
                        "name": "南充",
                        "key":"N"
                    },
                    {
                        "name": "南平",
                        "key":"N"
                    },
                    {
                        "name": "南通",
                        "key":"N"
                    },
                    {
                        "name": "南阳",
                        "key":"N"
                    }
                    ,
                    {
                        "name": "那曲",
                        "key":"N"
                    }

                    ,
                    {
                        "name": "内江",
                        "key":"N"
                    }
                    ,
                    {
                        "name": "宁德",
                        "key":"N"
                    }
                    ,
                    {
                        "name": "怒江",
                        "key":"N"
                    }


                ],
                "P":[

                    {
                        "name": "盘锦",
                        "key":"P"
                    }
                    ,
                    {
                        "name": "攀枝花",
                        "key":"P"
                    }
                    ,
                    {
                        "name": "平顶山",
                        "key":"P"
                    }
                    ,
                    {
                        "name": "平凉",
                        "key":"P"
                    }
                    ,
                    {
                        "name": "萍乡",
                        "key":"P"
                    }
                    ,
                    {
                        "name": "莆田",
                        "key":"P"
                    }
                    ,
                    {
                        "name": "濮阳",
                        "key":"P"
                    }

                ],
                "Q":[

                    {
                        "name": "青岛",
                        "key":"Q"
                    },
                    {
                        "name": "黔东南",
                        "key":"Q"
                    },
                    {
                        "name": "黔南",
                        "key":"Q"
                    },
                    {
                        "name": "黔西南",
                        "key":"Q"
                    },
                    {
                        "name": "庆阳",
                        "key":"Q"
                    },
                    {
                        "name": "清远",
                        "key":"Q"
                    },
                    {
                        "name": "秦皇岛",
                        "key":"Q"
                    }
                    ,
                    {
                        "name": "钦州",
                        "key":"Q"
                    }
                    ,
                    {
                        "name": "齐齐哈尔",
                        "key":"Q"
                    }
                    ,
                    {
                        "name": "泉州",
                        "key":"Q"
                    }
                    ,
                    {
                        "name": "曲靖",
                        "key":"Q"
                    }
                    ,
                    {
                        "name": "衢州",
                        "key":"Q"
                    }


                ],

                "R":[
                    {
                        "name": "日喀则",
                        "key":"R"
                    },
                    {
                        "name": "日照",
                        "key":"R"
                    }
                ]
                ,

                "S":[
                    {
                        "name": "上海",
                        "key":"S"
                    },
                    {
                        "name": "深圳",
                        "key":"S"
                    },
                    {
                        "name": "苏州",
                        "key":"S"
                    },
                    {
                        "name": "沈阳",
                        "key":"S"
                    },
                    {
                        "name": "石家庄",
                        "key":"S"
                    },
                    {
                        "name": "三门峡",
                        "key":"S"
                    },
                    {
                        "name": "三明",
                        "key":"S"
                    }
                    ,
                    {
                        "name": "三亚",
                        "key":"S"
                    }

                    ,
                    {
                        "name": "商洛",
                        "key":"S"
                    }

                    ,
                    {
                        "name": "商丘",
                        "key":"S"
                    }
                    ,
                    {
                        "name": "上饶",
                        "key":"S"
                    }
                    ,
                    {
                        "name": "山南",
                        "key":"S"
                    }
                    ,
                    {
                        "name": "汕头",
                        "key":"S"
                    }
                    ,
                    {
                        "name": "汕尾",
                        "key":"S"
                    }
                    ,
                    {
                        "name": "韶关",
                        "key":"S"
                    }
                    ,

                    {
                        "name": "绍兴",
                        "key":"S"
                    }

                    ,
                    {
                        "name": "邵阳",
                        "key":"S"
                    }
                    ,
                    {
                        "name": "十堰",
                        "key":"S"
                    }
                    ,
                    {
                        "name": "朔州",
                        "key":"S"
                    }
                    ,
                    {
                        "name": "四平",
                        "key":"S"
                    }
                    ,
                    {
                        "name": "绥化",
                        "key":"S"
                    }
                    ,
                    {
                        "name": "遂宁",
                        "key":"S"
                    }
                    ,

                    {
                        "name": "随州",
                        "key":"S"
                    }
                    ,

                    {
                        "name": "娄底",
                        "key":"S"
                    }
                    ,
                    {
                        "name": "宿迁",
                        "key":"S"
                    }
                    ,
                    {
                        "name": "宿州",
                        "key":"S"
                    }

                ],
                "T":[

                    {
                        "name": "天津",
                        "key":"T"
                    },
                    {
                        "name": "太原",
                        "key":"T"
                    },
                    {
                        "name": "泰安",
                        "key":"T"
                    },
                    {
                        "name": "泰州",
                        "key":"T"
                    },
                    {
                        "name": "唐山",
                        "key":"T"
                    },
                    {
                        "name": "天水",
                        "key":"T"
                    },
                    {
                        "name": "铁岭",
                        "key":"T"
                    }
                    ,
                    {
                        "name": "铜川",
                        "key":"T"
                    }
                    ,

                    {
                        "name": "通化",
                        "key":"T"
                    }
                    ,
                    {
                        "name": "通辽",
                        "key":"T"
                    }
                    ,
                    {
                        "name": "铜陵",
                        "key":"T"
                    }
                    ,
                    {
                        "name": "铜仁",
                        "key":"T"
                    }
                    ,
                    {
                        "name": "台湾",
                        "key":"T"
                    }


                ]
                ,
                "W":[

                    {
                        "name": "武汉",
                        "key":"W"
                    },
                    {
                        "name": "乌鲁木齐",
                        "key":"W"
                    },
                    {
                        "name": "无锡",
                        "key":"W"
                    },
                    {
                        "name": "威海",
                        "key":"W"
                    },
                    {
                        "name": "潍坊",
                        "key":"W"
                    },
                    {
                        "name": "文山",
                        "key":"W"
                    },
                    {
                        "name": "温州",
                        "key":"W"
                    }
                    ,
                    {
                        "name": "乌海",
                        "key":"W"
                    }
                    ,

                    {
                        "name": "芜湖",
                        "key":"W"
                    }
                    ,
                    {
                        "name": "乌兰察布",
                        "key":"W"
                    }
                    ,
                    {
                        "name": "武威",
                        "key":"W"
                    }
                    ,
                    {
                        "name": "梧州",
                        "key":"W"
                    }

                ],
                "X":[

                    {
                        "name": "厦门",
                        "key":"X"
                    },
                    {
                        "name": "西安",
                        "key":"X"
                    },
                    {
                        "name": "西宁",
                        "key":"X"
                    },
                    {
                        "name": "襄樊",
                        "key":"X"
                    },
                    {
                        "name": "湘潭",
                        "key":"X"
                    },
                    {
                        "name": "湘西",
                        "key":"X"
                    },
                    {
                        "name": "咸宁",
                        "key":"X"
                    }
                    ,
                    {
                        "name": "咸阳",
                        "key":"X"
                    }
                    ,

                    {
                        "name": "孝感",
                        "key":"X"
                    }
                    ,
                    {
                        "name": "邢台",
                        "key":"X"
                    }
                    ,
                    {
                        "name": "新乡",
                        "key":"X"
                    }
                    ,
                    {
                        "name": "信阳",
                        "key":"X"
                    }
                    ,
                    {
                        "name": "新余",
                        "key":"X"
                    }
                    ,
                    {
                        "name": "忻州",
                        "key":"X"
                    }
                    ,
                    {
                        "name": "西双版纳",
                        "key":"X"
                    }

                    ,
                    {
                        "name": "宣城",
                        "key":"X"
                    }
                    ,

                    {
                        "name": "许昌",
                        "key":"X"
                    }
                    ,
                    {
                        "name": "徐州",
                        "key":"X"
                    }
                    ,
                    {
                        "name": "香港",
                        "key":"X"
                    }
                    ,
                    {
                        "name": "锡林郭勒",
                        "key":"X"
                    }
                    ,
                    {
                        "name": "兴安",
                        "key":"X"
                    }
                ]
                ,
                "Y":[

                    {
                        "name": "银川",
                        "key":"Y"
                    },
                    {
                        "name": "雅安",
                        "key":"Y"
                    },
                    {
                        "name": "延安",
                        "key":"Y"
                    },
                    {
                        "name": "延边",
                        "key":"Y"
                    },
                    {
                        "name": "盐城",
                        "key":"Y"
                    },
                    {
                        "name": "阳江",
                        "key":"Y"
                    },

                    {
                        "name": "阳泉",
                        "key":"Y"
                    }
                    ,
                    {
                        "name": "扬州",
                        "key":"Y"
                    }
                    ,

                    {
                        "name": "烟台",
                        "key":"Y"
                    }
                    ,
                    {
                        "name": "宜宾",
                        "key":"Y"
                    }
                    ,
                    {
                        "name": "宜昌",
                        "key":"Y"
                    }
                    ,
                    {
                        "name": "宜春",
                        "key":"Y"
                    }
                    ,
                    {
                        "name": "营口",
                        "key":"Y"
                    }
                    ,

                    {
                        "name": "益阳",
                        "key":"Y"
                    }
                    ,
                    {
                        "name": "永州",
                        "key":"Y"
                    }

                    ,
                    {
                        "name": "岳阳",
                        "key":"Y"
                    }
                    ,

                    {
                        "name": "榆林",
                        "key":"Y"
                    }
                    ,
                    {
                        "name": "运城",
                        "key":"Y"
                    }
                    ,
                    {
                        "name": "云浮",
                        "key":"Y"
                    }
                    ,
                    {
                        "name": "玉树",
                        "key":"Y"
                    }
                    ,
                    {
                        "name": "玉溪",
                        "key":"Y"
                    }
                    ,
                    {
                        "name": "玉林",
                        "key":"Y"
                    }

                ],

                "Z":[
                    {
                        "name": "杂多县",
                        "key":"Z"
                    },
                    {
                        "name": "赞皇县",
                        "key":"Z"
                    },
                    {
                        "name": "枣强县",
                        "key":"Z"
                    },
                    {
                        "name": "枣阳市",
                        "key":"Z"
                    },
                    {
                        "name": "枣庄",
                        "key":"Z"
                    },
                    {
                        "name": "泽库县",
                        "key":"Z"
                    },
                    {
                        "name": "增城市",
                        "key":"Z"
                    }
                    ,

                    {
                        "name": "曾都区",
                        "key":"Z"
                    }
                    ,
                    {
                        "name": "泽普县",
                        "key":"Z"
                    }

                    ,
                    {
                        "name": "泽州县",
                        "key":"Z"
                    }
                    ,
                    {
                        "name": "札达县",
                        "key":"Z"
                    }
                    ,
                    {
                        "name": "扎赉特旗",
                        "key":"Z"
                    }
                    ,
                    {
                        "name": "扎兰屯市",
                        "key":"Z"
                    }
                    ,
                    {
                        "name": "扎鲁特旗",
                        "key":"Z"
                    }
                    ,

                    {
                        "name": "扎囊县",
                        "key":"Z"
                    }
                    ,
                    {
                        "name": "张北县",
                        "key":"Z"
                    }

                    ,
                    {
                        "name": "张店区",
                        "key":"Z"
                    }
                    ,
                    {
                        "name": "章贡区",
                        "key":"Z"
                    }
                    ,
                    {
                        "name": "张家港",
                        "key":"Z"
                    }
                    ,
                    {
                        "name": "张家界",
                        "key":"Z"
                    }
                    ,
                    {
                        "name": "张家口",
                        "key":"Z"
                    }
                    ,
                    {
                        "name": "漳平市",
                        "key":"Z"
                    }
                    ,

                    {
                        "name": "漳浦县",
                        "key":"Z"
                    }
                    ,

                    {
                        "name": "章丘市",
                        "key":"Z"
                    }
                    ,
                    {
                        "name": "樟树市",
                        "key":"Z"
                    }
                    ,
                    {
                        "name": "张湾区",
                        "key":"Z"
                    },
                    {
                        "name": "彰武县",
                        "key":"Z"
                    },
                    {
                        "name": "漳县",
                        "key":"Z"
                    },
                    {
                        "name": "张掖",
                        "key":"Z"
                    },
                    {
                        "name": "漳州",
                        "key":"Z"
                    },
                    {
                        "name": "长子县",
                        "key":"Z"
                    }
                    ,

                    {
                        "name": "湛河区",
                        "key":"Z"
                    }
                    ,
                    {
                        "name": "湛江",
                        "key":"Z"
                    }
                    ,

                    {
                        "name": "站前区",
                        "key":"Z"
                    }
                    ,
                    {
                        "name": "沾益县",
                        "key":"Z"
                    }
                    ,
                    {
                        "name": "诏安县",
                        "key":"Z"
                    },
                    {
                        "name": "召陵区",
                        "key":"Z"
                    },
                    {
                        "name": "昭平县",
                        "key":"Z"
                    },
                    {
                        "name": "肇庆",
                        "key":"Z"
                    },
                    {
                        "name": "昭通",
                        "key":"Z"
                    },
                    {
                        "name": "赵县",
                        "key":"Z"
                    }

                ]
            }
        ]


        return {
            all: function() {
                console.log();
                return city;
            },
            getCity:function(keyWords){
                console.log(keyWords);
                var str = "ABCDEFGHIJKLMNOPQRSTUVWXYZ";
                var result = [];
                for (var i = 0; i < str.length; i++) {
                    var nextChar = str.charAt(i);
                    var newVar = city[0][nextChar];
                    var j = 0;
                    for (j in city[0][nextChar]) {
                        if (newVar[j].name.indexOf(keyWords) != -1) {
                            result.push(newVar[j]);
                        }
                    }
                }
                return result;
            },
            getCurrentCityName:function(){
                //当前所在城市
                function myFun(result) {
                    var cityName = result.name;
                    $rootScope.curCityName = cityName.replace("市",'');
                    $rootScope.cityLat = result.center.lat;
                    $rootScope.cityLng = result.center.lng;
                }

                var myCity = new BMap.LocalCity();
                myCity.get(myFun);
            }
        };
    })

    /**
     * var paramObj = Utils.objKeyConvert($scope.refund, 'refund');
     * var params = $.param(paramObj);
     */
    .factory('Utils', function () {
        return {
            objKeyConvert: function (obj, keyPrefix) {
                var data = {};
                angular.forEach(obj, function (v, k) {
                    if(v instanceof Date){
                        v = v.getFullYear() + '-' + (v.getMonth() + 1) + "-" + v.getDate();
                    }

                    data[keyPrefix + '.' + k] = $.trim(v);
                });
                return data;
            },

            replaceAll: function (content, oldStr, newStr) {
              while (content.indexOf(oldStr) > -1) {
                content = content.replace(oldStr, newStr);
              }
              return content;
            }
        }
    })

    //本地存储数据
    .factory('locals', function ($window) {
        return {
            //存储单个属性
            set: function (key, value) {
                $window.localStorage[key] = value;
            },
            //读取单个属性
            get: function (key, defaultValue) {
                return $window.localStorage[key] || defaultValue;
            },
            //存储对象，以JSON格式存储
            setObject: function (key, value) {
                $window.localStorage[key] = angular.toJson(value);
            },
            //读取对象
            getObject: function (key) {
                return angular.fromJson($window.localStorage[key] || '{}');
            },
            //删除数据
            delete: function (key) {
                delete $window.localStorage[key];
            },
            //删除订单所有缓存
            deletePayment: function () {
                var excludeKey = ['addressId','saveInvoiceInfo','goodsCount','couponId','invoiceType','invoiceTitle',
                  'invoiceContentType','invoiceDeliveryType','invoiceAddress','invoiceDetail', 'invoiceTaxId', 'invoiceFileIds', 'invoiceFiles'];
                angular.forEach($window.localStorage, function (v, k) {
                    angular.forEach(excludeKey, function (v1, k1) {
                        if(k.indexOf(excludeKey[k1]) != -1){
                            delete $window.localStorage[k];
                        }
                    });
                });
            },
            //
            deleteRefund: function () {
                var excludeKey = ['refundFile'];
                angular.forEach($window.localStorage, function (v, k) {
                    angular.forEach(excludeKey, function (v1, k1) {
                        if(k.indexOf(excludeKey[k1]) != -1){
                            delete $window.localStorage[k];
                        }
                    });
                });
            }
        }
  })


;
